Index: modules/features2d/include/opencv2/features2d/features2d.hpp
===================================================================
--- modules/features2d/include/opencv2/features2d/features2d.hpp	(revision 8283)
+++ modules/features2d/include/opencv2/features2d/features2d.hpp	(working copy)
@@ -508,13 +508,15 @@
      * gridRows            Grid rows count.
      * gridCols            Grid column count.
      */
-    CV_WRAP GridAdaptedFeatureDetector( const Ptr<FeatureDetector>& detector,
+    CV_WRAP GridAdaptedFeatureDetector( const Ptr<FeatureDetector>& detector = 0,
                                         int maxTotalKeypoints=1000,
                                         int gridRows=4, int gridCols=4 );
     
     // TODO implement read/write
     virtual bool empty() const;
 
+    AlgorithmInfo* info() const;
+
 protected:
     virtual void detectImpl( const Mat& image, vector<KeyPoint>& keypoints, const Mat& mask=Mat() ) const;
 
Index: modules/features2d/src/features2d_init.cpp
===================================================================
--- modules/features2d/src/features2d_init.cpp	(revision 8283)
+++ modules/features2d/src/features2d_init.cpp	(working copy)
@@ -248,6 +248,25 @@
     return &dense_info;
 }    
 
+static Algorithm* createGridAdapted() { return new GridAdaptedFeatureDetector; }
+static AlgorithmInfo grid_adapted_info("Feature2D.Grid", createGridAdapted);
+
+AlgorithmInfo* GridAdaptedFeatureDetector::info() const
+{
+    static volatile bool initialized = false;
+    if( !initialized )
+    {
+        GridAdaptedFeatureDetector obj;
+        grid_adapted_info.addParam(obj, "detector", (Ptr<Algorithm>&) obj.detector);
+        grid_adapted_info.addParam(obj, "maxTotalKeypoints", obj.maxTotalKeypoints);
+        grid_adapted_info.addParam(obj, "gridRows", obj.gridRows);
+        grid_adapted_info.addParam(obj, "gridCols", obj.gridCols);
+
+        initialized = true;
+    }
+    return &grid_adapted_info;
+}
+
 bool initModule_features2d(void)
 {
     Ptr<Algorithm> brief = createBRIEF(), orb = createORB(),
